@@ -3,13 +3,13 @@ mpfrcx_get_version
 
 MPFRCX version
 
-Copyright (C) 2010, 2011, 2012, 2013 Andreas Enge
+Copyright (C) 2010, 2011, 2012, 2013, 2018 Andreas Enge
 
 This file is part of the MPFRCX Library.
 
 The MPFRCX Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The MPFRCX Library is distributed in the hope that it will be useful, but
@@ -18,7 +18,7 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPC Library; see the file COPYING.LIB.  If not, write to
+along with the MPFRCX library; see the file COPYING.LESSER.  If not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 MA 02111-1307, USA.
 */
@@ -26,5 +26,5 @@ MA 02111-1307, USA.
 #include "mpfrcx-impl.h"
 
 const char * mpfrcx_get_version (void) {
-  return "0.4.2";
+  return "0.5";
 }
